summaryrefslogtreecommitdiff
path: root/include/llvm/MC/MCExpr.h
diff options
context:
space:
mode:
authorJim Grosbach <grosbach@apple.com>2010-11-10 03:26:07 +0000
committerJim Grosbach <grosbach@apple.com>2010-11-10 03:26:07 +0000
commit2c4d5125c708bb35140fc2a40b02beb1add101db (patch)
tree54de4c5d66ac53c03c0b8f5c0e9799fcbc75e67f /include/llvm/MC/MCExpr.h
parent0cf2b2b9f0c4f9fc18ef527a227045793a769dee (diff)
downloadllvm-2c4d5125c708bb35140fc2a40b02beb1add101db.tar.gz
llvm-2c4d5125c708bb35140fc2a40b02beb1add101db.tar.bz2
llvm-2c4d5125c708bb35140fc2a40b02beb1add101db.tar.xz
Update ARMConstantPoolValue to not use a modifier string. Use an explicit
VariantKind marker to indicate the additional information necessary. Update MC to handle the new Kinds. rdar://8647623 git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@118671 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/MC/MCExpr.h')
-rw-r--r--include/llvm/MC/MCExpr.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/include/llvm/MC/MCExpr.h b/include/llvm/MC/MCExpr.h
index 51b1f83884..3f25dc0562 100644
--- a/include/llvm/MC/MCExpr.h
+++ b/include/llvm/MC/MCExpr.h
@@ -141,9 +141,15 @@ public:
VK_TLSLDM,
VK_TPOFF,
VK_DTPOFF,
- VK_ARM_HI16, // The R_ARM_MOVT_ABS relocation (:upper16: in the asm file)
- VK_ARM_LO16, // The R_ARM_MOVW_ABS_NC relocation (:lower16: in the asm file)
- VK_ARM_PLT, // ARM-style PLT symbol references. i.e., (PLT) instead of @PLT
+ VK_ARM_HI16, // The R_ARM_MOVT_ABS relocation (:upper16: in the .s file)
+ VK_ARM_LO16, // The R_ARM_MOVW_ABS_NC relocation (:lower16: in the .w file)
+ // FIXME: We'd really like to use the generic Kinds listed above for these.
+ VK_ARM_PLT, // ARM-style PLT references. i.e., (PLT) instead of @PLT
+ VK_ARM_TLSGD, // ditto for TLSGD, GOT, GOTOFF, TPOFF and GOTTPOFF
+ VK_ARM_GOT,
+ VK_ARM_GOTOFF,
+ VK_ARM_TPOFF,
+ VK_ARM_GOTTPOFF,
VK_TLVP // Mach-O thread local variable relocation
};